#!/usr/bin/python
# -*- coding:utf-8 -*-

from dom import *
import scorecard
import makelogo

def newInstance():
    return JLeagueDivisionOneNS2005()

class JLeagueDivisionOneNS2005 ( scorecard.ScoreCard ):
    def __init__( self ):
        scorecard.ScoreCard.__init__( self )
        self.date = None
        self.games = []
        return
        
    def getName( self ):
        return "J１ (nikkansports.com)"

    def getVersion( self ):
        return "1.0"

    def getSportsCategory( self ):
        return "soccer"

    def getCountry( self ):
        return "Japan"

    def getURL( self ):
        return "http://www.nikkansports.com/ns/soccer/jleague/score/j1_nscore.html"

    def getLanguage( self ):
        return 'ja'

    def getEncoding( self ):
        return 'sjis'

    def getStartKeyword( self ):
        return "<!--====タイトルテーブルエリア====-->"

    def getEndKeyword( self ):
        return "<!-- Start of Footer -->"

    def getIcon( self, team ):
        if team == "鹿島": name = 'kashima'
        elif team == "広島": name = 'hiroshima'
        elif team == "Ｇ大阪": name = 'gosaka'
        elif team == "名古屋": name = 'nagoya'
        elif team == "千葉": name = 'chiba'
        elif team == "磐田": name = 'iwata'
        elif team == "大宮": name = 'omiya'
        elif team == "横浜" or team == "横浜FM" or team == "横浜ＦＭ" or team == "横浜Ｍ": name = 'yokohamafm'
        elif team == "柏": name = 'kashiwa'
        elif team == "東京": name = 'fctokyo'
        elif team == "浦和": name = 'urawa'
        elif team == "東京Ｖ": name = 'tokyov'
        elif team == "Ｃ大阪": name = 'cosaka'
        elif team == "川崎Ｆ": name = 'kawasaki'
        elif team == "清水": name = 'shimizu'
        elif team == "神戸": name = 'kobe'
        elif team == "大分": name = 'oita'
        elif team == "新潟": name = 'niigata'
        elif team == "京都": name = 'kyoto'
        elif team == "鳥栖": name = 'tosu'
        elif team == "福岡": name = 'fukuoka'
        elif team == "札幌": name = 'sapporo'
        elif team == "仙台": name = 'sendai'
        elif team == "山形": name = 'yamagata'
        elif team == "草津": name = 'kusatsu'
        elif team == "徳島": name = 'tokushima'
        elif team == "甲府": name = 'kofu'
        elif team == "湘南": name = 'shonan'
        elif team == "横浜ＦＣ" or team == "横浜FC" or team == "横浜Ｃ" or team == "横浜C" : name = 'yokohamafc'
        elif team == "水戸": name = 'mito'
        else: return ""

        try:
            uri = makelogo.getURI( 'http://www.j-league.or.jp/club/%s/images/emblem.gif' % name , 'jleague', '%s' % name )
            return '<td class="teamlogo"><img src="%s" class="logo"/></td>' % uri
        except:
            return ''
        pass
        

    def resolve_game( self, element ):
        elem_status = element.get_element_at_path( "tr/td/table/tr,2" )
        status = elem_status.get_text()
        elem_game = elem_status.next_sibling()
        team1 = elem_game.get_element_at_path( "th/span" ).get_text()
        goal1 = elem_game.get_element_at_path( "th,2" ).get_text()
        goal2 = elem_game.get_element_at_path( "th,4" ).get_text()
        team2 = elem_game.get_element_at_path( "th,5/span" ).get_text()
        return [ team1, team2, goal1, goal2, status ]

    def interpreteDocument( self, document ):
        elem_date = document.get_element_at_path( "/html/table/tr,3/td/table/tr/td,3" )
        elem_date = document.get_element_at_path( "/html/table/tr,3/td/table/tr/td" )
        import re, sys
        while elem_date != None:
            text = elem_date.get_text( " " )
            if re.search( "\\d+/\\d+/\\d+", text ):
                self.date = text
                break
            try:
                elem_date = elem_date.next_sibling( 'td' )
            except:
                break
            pass

        elem = document.get_element_at_path( "/html/div/table/tr/td" )
        e = elem.get_element_at_path( 'table' )
        while e != None:
            gamestatus = self.resolve_game( e )
            if gamestatus != None:
                self.games.append( gamestatus )
                pass
            try:
                e = e.next_sibling( 'table' )
            except:
                break
            pass
        return

    def getDate( self ):
        if not self.date:
            return ""
        return self.date

    def toHTML( self ):
        import re
        html = self.html_header()
        title = self.getName()
        html += "<body>"
        #title = re.sub( "nikk", "", title )
        #title = re.sub( "\\\([^\\\)]+\\\)", "", title )
        title = re.sub( "\([^\)]*\)$", "", title )
        if len( self.games ) > 0:
            html += '<span class="tabletitle">%s %s</span>' % ( title, self.getDate() )
            html += "<table>"
            for game in self.games:
                lastcolumn = ""
                if len( game ) > 4:
                    lastcolumn = game[ 4 ]
                    pass
                team1 = self.getIcon( game[ 0 ] ) \
                        + '<td class="team">%s</td>' % game[ 0 ]
                team2 = '<td class="team">%s</td>' % game[ 1 ] \
                        + self.getIcon( game[ 1 ] )
                html += '<tr>%s<td class="score">%s - %s</td>%s<td class=\"status\">%s</td></tr>\n' % ( team1, game[ 2 ], game[ 3 ], team2, lastcolumn )
                pass
            html += "</table>"
        else:
            html += "<div id=\"error\">Could not load data</div>"
            pass
        html += "</body>"
        html += self.html_footer()
        return html        
    pass

